@@ -30,7 +30,6 @@ namespace Client
 {
 class ConnectionThread;
 class Registry;
-class PlasmaShell;
 }
 }
 
@@ -66,19 +65,19 @@ public:
     void setKsldSocket(int socket);
     void setDefaultToSwitchUser(bool defaultToSwitchUser);
 
-    void osdProgress(const QString &icon, int percent, const QString &additionalText);
-    void osdText(const QString &icon, const QString &additionalText);
-    void updateCanSuspend(bool set);
-    void updateCanHibernate(bool set);
+    void updateCanSuspend();
+    void updateCanHibernate();
 
 public Q_SLOTS:
-    void desktopResized();
-    void onScreenAdded(QScreen *screen);
+    void osdProgress(const QString &icon, int percent, const QString &additionalText);
+    void osdText(const QString &icon, const QString &additionalText);
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
 private Q_SLOTS:
+    void handleScreen(QScreen *screen);
+    KQuickAddons::QuickViewSharedEngine *createViewForScreen(QScreen *screen);
     void resetRequestIgnore();
     void suspendToRam();
     void suspendToDisk();
@@ -88,7 +87,6 @@ private Q_SLOTS:
 
 private:
     void initialize();
-    void initializeWayland();
     void shareEvent(QEvent *e, KQuickAddons::QuickViewSharedEngine *from);
     void loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view);
     void screenGeometryChanged(QScreen *screen, const QRect &geo);
@@ -119,7 +117,6 @@ private:
     QThread *m_ksldConnectionThread = nullptr;
     org_kde_ksld *m_ksldInterface = nullptr;
 
-    KWayland::Client::PlasmaShell *m_plasmaShell = nullptr;
     WallpaperIntegration *m_wallpaperIntegration;
     LnFIntegration *m_lnfIntegration;
 };
