@@ -177,7 +177,7 @@ void KSldApp::initialize()
     }
 
     // idle support
-    auto idleTimeSignal = static_cast<void (KIdleTime::*)(int)>(&KIdleTime::timeoutReached);
+    auto idleTimeSignal = static_cast<void (KIdleTime::*)(int, int)>(&KIdleTime::timeoutReached);
     connect(KIdleTime::instance(), idleTimeSignal, this, [this](int identifier) {
         if (identifier != m_idleId) {
             // not our identifier
@@ -331,6 +331,9 @@ void KSldApp::initialize()
     if (m_logind->isLocked()) {
         lock(EstablishLock::Immediate);
     }
+    if (KScreenSaverSettings::lockOnStart()) {
+        lock(EstablishLock::Immediate);
+    }
 }
 
 void KSldApp::configure()
